vsutillib.log package
=====================

The ``LogRotateFileHandler`` class
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: vsutillib.log.LogRotateFileHandler
    :show-inheritance:

.. inheritance-diagram:: vsutillib.log.LogRotateFileHandler
    :parts: 1
